@@ -315,8 +315,11 @@ def LickMicroStructure_stone(dFrame_lick,latency_array, bout_crit):
     ILIs_win_bouts = [[] if x == 0 else x[1:] for x in ILIs_win_bouts]
     dFrame_lick["Bouts"] = bouts
     dFrame_lick["ILIs"] = ILIs_win_bouts         
-    dFrame_lick["Lat_First"] = latency_array[:,1]
-    #Return the appended dataframe
+    if latency_array.shape[1] >= 2:
+        dFrame_lick["Lat_First"] = latency_array[:, 1]
+    else:
+        # Handle the case when the array doesn't have enough columns
+        dFrame_lick["Lat_First"] = np.nan
     return dFrame_lick	    
 
 # =============================================================================
